summaryrefslogtreecommitdiffhomepage
path: root/runsc/boot/config.go
diff options
context:
space:
mode:
authorFabricio Voznika <fvoznika@google.com>2018-10-11 14:28:15 -0700
committerShentubot <shentubot@google.com>2018-10-11 14:29:37 -0700
commite68d86e1bd47f7905e4452f7ce0e04e683561f85 (patch)
treef5e9ff902d3efbee1c33c9f2d5064f57cde977d2 /runsc/boot/config.go
parent96c68b36f67355295339e8039712b28d272e083e (diff)
Make debug log file name configurable
This is a breaking change if you're using --debug-log-dir. The fix is to replace it with --debug-log and add a '/' at the end: --debug-log-dir=/tmp/runsc ==> --debug-log=/tmp/runsc/ PiperOrigin-RevId: 216761212 Change-Id: I244270a0a522298c48115719fa08dad55e34ade1
Diffstat (limited to 'runsc/boot/config.go')
-rw-r--r--runsc/boot/config.go7
1 files changed, 3 insertions, 4 deletions
diff --git a/runsc/boot/config.go b/runsc/boot/config.go
index cd977c8a5..41af084b9 100644
--- a/runsc/boot/config.go
+++ b/runsc/boot/config.go
@@ -160,9 +160,8 @@ type Config struct {
// LogFormat is the log format, "text" or "json".
LogFormat string
- // DebugLogDir is the directory to log debug information to, if not
- // empty.
- DebugLogDir string
+ // DebugLog is the path to log debug information to, if not empty.
+ DebugLog string
// FileAccess indicates how the filesystem is accessed.
FileAccess FileAccessType
@@ -217,7 +216,7 @@ func (c *Config) ToFlags() []string {
"--debug=" + strconv.FormatBool(c.Debug),
"--log=" + c.LogFilename,
"--log-format=" + c.LogFormat,
- "--debug-log-dir=" + c.DebugLogDir,
+ "--debug-log=" + c.DebugLog,
"--file-access=" + c.FileAccess.String(),
"--overlay=" + strconv.FormatBool(c.Overlay),
"--network=" + c.Network.String(),